@@ -1,16 +1,17 @@
-let crypto = require('crypto')
+import { randomFill } from 'crypto'
 
-let { urlAlphabet } = require('../url-alphabet')
+import { urlAlphabet } from '../url-alphabet/index.js'
 
 // `crypto.randomFill()` is a little faster than `crypto.randomBytes()`,
 // because it is possible to use in combination with `Buffer.allocUnsafe()`.
-let random = bytes =>
+export let random = bytes =>
   new Promise((resolve, reject) => {
     // `Buffer.allocUnsafe()` is faster because it doesn’t flush the memory.
     // Memory flushing is unnecessary since the buffer allocation itself resets
     // the memory with the new bytes.
-    crypto.randomFill(Buffer.allocUnsafe(bytes), (err, buf) => {
+    randomFill(Buffer.allocUnsafe(bytes), (err, buf) => {
       if (err) {
+        /* c8 ignore next */
         reject(err)
       } else {
         resolve(buf)
@@ -18,7 +19,7 @@ let random = bytes =>
     })
   })
 
-let customAlphabet = (alphabet, defaultSize = 21) => {
+export let customAlphabet = (alphabet, defaultSize = 21) => {
   // First, a bitmask is necessary to generate the ID. The bitmask makes bytes
   // values closer to the alphabet size. The bitmask calculates the closest
   // `2^31 - 1` number, which exceeds the alphabet size.
@@ -47,13 +48,14 @@ let customAlphabet = (alphabet, defaultSize = 21) => {
         id += alphabet[bytes[i] & mask] || ''
         if (id.length === size) return id
       }
+      /* c8 ignore next */
       return tick(id, size)
     })
 
   return size => tick('', size)
 }
 
-let nanoid = (size = 21) =>
+export let nanoid = (size = 21) =>
   random(size).then(bytes => {
     let id = ''
     // A compact alternative for `for (var i = 0; i < step; i++)`.
@@ -67,5 +69,3 @@ let nanoid = (size = 21) =>
     }
     return id
   })
-
-module.exports = { nanoid, customAlphabet, random }
