@@ -5,18 +5,21 @@ import * as browser from '../index.browser.js'
 import * as node from '../index.js'
 
 test.before(() => {
-  global.crypto = {
-    getRandomValues(array) {
-      for (let i = 0; i < array.length; i++) {
-        array[i] = Math.floor(Math.random() * 256)
+  Object.defineProperty(global, 'crypto', {
+    configurable: true,
+    value: {
+      getRandomValues(array) {
+        for (let i = 0; i < array.length; i++) {
+          array[i] = Math.floor(Math.random() * 256)
+        }
+        return array
       }
-      return array
     }
-  }
+  })
 })
 
 test.after(() => {
-  delete global.crypto
+  Object.defineProperty(global, 'crypto', { value: undefined })
 })
 
 for (let type of ['node', 'browser']) {
